Animation class

This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).

https://core.telegram.org/bots/api#animation

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Animation({required String fileId, required String fileUniqueId, required int width, required int height, required int duration, PhotoSize? thumbnail, String? fileName, String? mimeType, int? fileSize})
Animation.fromJson(Map<String, dynamic> json)
factory

Properties

duration ↔ int
getter/setter pair
duration_ ↔ Duration
getter/setter pair
fileId ↔ String
getter/setter pair
fileName ↔ String?
getter/setter pair
fileSize ↔ int?
getter/setter pair
fileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
mimeType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ PhotoSize?
getter/setter pair
width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited