Audio class

This object represents an audio file to be treated as music by the Telegram clients.

https://core.telegram.org/bots/api#audio

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Audio({required String fileId, required String fileUniqueId, required int duration, String? performer, String? title, String? fileName, String? mimeType, int? fileSize, PhotoSize? thumbnail})
Audio.fromJson(Map<String, dynamic> json)
factory

Properties

duration ↔ int
getter/setter pair
duration_ ↔ Duration
getter/setter pair
fileId ↔ String
getter/setter pair
fileName ↔ String?
getter/setter pair
fileSize ↔ int?
getter/setter pair
fileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
getter/setter pair
performer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ PhotoSize?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited