BotCommandScopeChat class

Represents the scope of bot commands, covering a specific chat.

https://core.telegram.org/bots/api#botcommandscopechat

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

BotCommandScopeChat({String type = BotCommandScope.typeChat, required dynamic chatId})
BotCommandScopeChat.fromJson(Map<String, dynamic> json)
factory

Properties

chatId ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited