Chat class

This object represents a chat.

https://core.telegram.org/bots/api#chat

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Chat({required int id, required String type, String? title, String? username, String? firstName, String? lastName, bool? isForum, ChatPhoto? photo, List<String>? activeUsernames, String? emojiStatusCustomEmojiId, String? emojiStatusExpirationDate, String? bio, bool? hasPrivateForwards, bool? hasRestrictedVoiceAndVideoMessages, bool? joinToSendMessages, bool? joinByRequest, String? description, String? inviteLink, Message? pinnedMessage, ChatPermissions? permissions, int? slowModeDelay, int? messageAutoDeleteTime, bool? hasAggressiveAntiSpamEnabled, bool? hasHiddenMembers, bool? hasProtectedContent, String? stickerSetName, bool? canSetStickerSet, int? linkedChatId, ChatLocation? location})
Chat.fromJson(Map<String, dynamic> json)
factory

Properties

activeUsernames ↔ List<String>?
getter/setter pair
bio ↔ String?
getter/setter pair
canSetStickerSet ↔ bool?
getter/setter pair
description ↔ String?
getter/setter pair
emojiStatusCustomEmojiId ↔ String?
getter/setter pair
emojiStatusExpirationDate ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hasAggressiveAntiSpamEnabled ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasHiddenMembers ↔ bool?
getter/setter pair
hasPrivateForwards ↔ bool?
getter/setter pair
hasProtectedContent ↔ bool?
getter/setter pair
hasRestrictedVoiceAndVideoMessages ↔ bool?
getter/setter pair
id ↔ int
getter/setter pair
getter/setter pair
isForum ↔ bool?
getter/setter pair
joinByRequest ↔ bool?
getter/setter pair
joinToSendMessages ↔ bool?
getter/setter pair
lastName ↔ String?
getter/setter pair
linkedChatId ↔ int?
getter/setter pair
location ↔ ChatLocation?
getter/setter pair
messageAutoDeleteTime ↔ int?
getter/setter pair
permissions ↔ ChatPermissions?
getter/setter pair
photo ↔ ChatPhoto?
getter/setter pair
pinnedMessage ↔ Message?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slowModeDelay ↔ int?
getter/setter pair
stickerSetName ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
type ↔ String
getter/setter pair
username ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

typeChannel → const String
typeGroup → const String
typePrivate → const String
typeSuperGroup → const String