ChatAdministratorRights class

Represents the rights of an administrator in a chat.

https://core.telegram.org/bots/api#chatadministratorrights

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ChatAdministratorRights({bool isAnonymous = false, bool canManageChat = false, bool canDeleteMessages = false, bool canManageVideoChats = false, bool canRestrictMembers = false, bool canPromoteMembers = false, bool canChangeInfo = false, bool canInviteUsers = false, bool? canPostMessages, bool? canEditMessages, bool? canPinMessages, bool? canManageTopics})
ChatAdministratorRights.fromJson(Map<String, dynamic> json)
factory

Properties

canChangeInfo ↔ bool
getter/setter pair
canDeleteMessages ↔ bool
getter/setter pair
canEditMessages ↔ bool?
getter/setter pair
canInviteUsers ↔ bool
getter/setter pair
canManageChat ↔ bool
getter/setter pair
canManageTopics ↔ bool?
getter/setter pair
canManageVideoChats ↔ bool
getter/setter pair
canPinMessages ↔ bool?
getter/setter pair
canPostMessages ↔ bool?
getter/setter pair
canPromoteMembers ↔ bool
getter/setter pair
canRestrictMembers ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited