ChatJoinRequest class

Represents a join request sent to a chat.

https://core.telegram.org/bots/api#chatjoinrequest

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ChatJoinRequest({required Chat chat, required User from, required int userChatId, required int date, String? bio, ChatInviteLink? inviteLink})
ChatJoinRequest.fromJson(Map<String, dynamic> json)
factory

Properties

bio ↔ String?
getter/setter pair
chat ↔ Chat
getter/setter pair
date ↔ int
getter/setter pair
date_ ↔ DateTime
getter/setter pair
from ↔ User
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userChatId ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited