ChatMemberAdministrator class

Represents a chat member that has some additional privileges.

https://core.telegram.org/bots/api#chatmemberadministrator

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ChatMemberAdministrator({required String status, required User user, bool canBeEdited = false, bool isAnonymous = false, bool canManageChat = false, bool canDeleteMessages = false, bool canManageVideoChats = false, bool canRestrictMembers = false, bool canPromoteMembers = false, bool canChangeInfo = false, bool canInviteUsers = false, bool? canPostMessages, bool? canEditMessages, bool? canPinMessages, bool? canManageTopics, String? customTitle})
ChatMemberAdministrator.fromJson(Map<String, dynamic> json)
factory

Properties

canBeEdited ↔ bool
getter/setter pair
canChangeInfo ↔ bool
getter/setter pair
canDeleteMessages ↔ bool
getter/setter pair
canEditMessages ↔ bool?
getter/setter pair
canInviteUsers ↔ bool
getter/setter pair
canManageChat ↔ bool
getter/setter pair
canManageTopics ↔ bool?
getter/setter pair
canManageVideoChats ↔ bool
getter/setter pair
canPinMessages ↔ bool?
getter/setter pair
canPostMessages ↔ bool?
getter/setter pair
canPromoteMembers ↔ bool
getter/setter pair
canRestrictMembers ↔ bool
getter/setter pair
customTitle ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
getter/setter pairoverride
user ↔ User
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited