ChatMemberUpdated class

This object represents changes in the status of a chat member.

https://core.telegram.org/bots/api#chatmemberupdated

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ChatMemberUpdated({Chat? chat, User? from, ChatMember? oldChatMember, ChatMember? newChatMember, ChatInviteLink? inviteLink, bool? viaChatFolderInviteLink, int? date})
ChatMemberUpdated.fromJson(Map<String, dynamic> json)
factory

Properties

chat ↔ Chat?
getter/setter pair
date ↔ int?
getter/setter pair
date_ ↔ DateTime?
getter/setter pair
from ↔ User?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
newChatMember ↔ ChatMember?
getter/setter pair
oldChatMember ↔ ChatMember?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited