ChatPermissions class

Describes actions that a non-administrator user is allowed to take in a chat.

https://core.telegram.org/bots/api#chatpermissions

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ChatPermissions({bool? canSendMessages, bool? canSendAudios, bool? canSendDocuments, bool? canSendPhotos, bool? canSendVideos, bool? canSendVideoNotes, bool? canSendVoiceNotes, bool? canSendPolls, bool? canSendOtherMessages, bool? canAddWebPagePreviews, bool? canChangeInfo, bool? canInviteUsers, bool? canPinMessages, bool? canManageTopics})
ChatPermissions.fromJson(Map<String, dynamic> json)
factory

Properties

canAddWebPagePreviews ↔ bool?
getter/setter pair
canChangeInfo ↔ bool?
getter/setter pair
canInviteUsers ↔ bool?
getter/setter pair
canManageTopics ↔ bool?
getter/setter pair
canPinMessages ↔ bool?
getter/setter pair
canSendAudios ↔ bool?
getter/setter pair
canSendDocuments ↔ bool?
getter/setter pair
canSendMessages ↔ bool?
getter/setter pair
canSendOtherMessages ↔ bool?
getter/setter pair
canSendPhotos ↔ bool?
getter/setter pair
canSendPolls ↔ bool?
getter/setter pair
canSendVideoNotes ↔ bool?
getter/setter pair
canSendVideos ↔ bool?
getter/setter pair
canSendVoiceNotes ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited