ChatPhoto class

This object represents a chat photo.

https://core.telegram.org/bots/api#chatphoto

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ChatPhoto({required String smallFileId, required String smallFileUniqueId, required String bigFileId, required String bigFileUniqueId})
ChatPhoto.fromJson(Map<String, dynamic> json)
factory

Properties

bigFileId ↔ String
getter/setter pair
bigFileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallFileId ↔ String
getter/setter pair
smallFileUniqueId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited