Contact class

This object represents a phone contact.

https://core.telegram.org/bots/api#contact

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Contact({required String phoneNumber, required String firstName, String? lastName, int? userId, String? vcard})
Contact.fromJson(Map<String, dynamic> json)
factory

Properties

firstName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastName ↔ String?
getter/setter pair
phoneNumber ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ int?
getter/setter pair
vcard ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited