Dice class

This object represents an animated emoji that displays a random value.

https://core.telegram.org/bots/api#dice

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Dice({required int value, required String emoji})
Dice.fromJson(Map<String, dynamic> json)
factory

Properties

emoji ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

emojiBasketball → const String
emojiBowling → const String
emojiDart → const String
emojiDice → const String
emojiFootball → const String
emojiSlotMachine → const String