Document class

This object represents a general file (as opposed to photos, voice messages and audio files).

https://core.telegram.org/bots/api#document

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Document({required String fileId, required String fileUniqueId, PhotoSize? thumbnail, String? fileName, String? mimeType, int? fileSize})
Document.fromJson(Map<String, dynamic> json)
factory

Properties

fileId ↔ String
getter/setter pair
fileName ↔ String?
getter/setter pair
fileSize ↔ int?
getter/setter pair
fileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ PhotoSize?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited