File class

This object represents a file ready to be downloaded.

The file can be downloaded via the link https://api.telegram.org/file/bot<token>/<file_path>. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling getFile.

Maximum file size to download is 20 MB

https://core.telegram.org/bots/api#file

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

File({required String fileId, required String fileUniqueId, int? fileSize, String? filePath})
File.fromJson(Map<String, dynamic> json)
factory

Properties

fileId ↔ String
getter/setter pair
filePath ↔ String?
getter/setter pair
fileSize ↔ int?
getter/setter pair
fileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited