Game class

This object represents a game.

Use BotFather to create and edit games, their short names will act as unique identifiers.

https://core.telegram.org/bots/api#game

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Game({required String title, required String description, required List<PhotoSize> photo, String? text, List<MessageEntity>? textEntities, Animation? animation})
Game.fromJson(Map<String, dynamic> json)
factory

Properties

animation ↔ Animation?
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
photo ↔ List<PhotoSize>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair
textEntities ↔ List<MessageEntity>?
getter/setter pair
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited