InlineKeyboardButton class

This object represents one button of an inline keyboard.

You must use exactly one of the optional fields.

https://core.telegram.org/bots/api#inlinekeyboardbutton

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineKeyboardButton({required String text, String? url, String? callbackData, WebAppInfo? webApp, LoginUrl? loginUrl, String? switchInlineQuery, String? switchInlineQueryCurrentChat, CallbackGame? callbackGame, bool? pay, SwitchInlineQueryChosenChat? switchInlineQueryChosenChat})
InlineKeyboardButton.fromJson(Map<String, dynamic> json)
factory

Properties

callbackData ↔ String?
getter/setter pair
callbackGame ↔ CallbackGame?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loginUrl ↔ LoginUrl?
getter/setter pair
pay ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchInlineQuery ↔ String?
getter/setter pair
switchInlineQueryChosenChat ↔ SwitchInlineQueryChosenChat?
getter/setter pair
switchInlineQueryCurrentChat ↔ String?
getter/setter pair
text ↔ String
getter/setter pair
url ↔ String?
getter/setter pair
webApp ↔ WebAppInfo?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited