InlineQuery class

This object represents an incoming inline query.

When the user sends an empty query, your bot could return some default or trending results.

https://core.telegram.org/bots/api#inlinequery

Implementers
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQuery({required String id, required User from, required String query, required String offset, String? chatType, Location? location})
InlineQuery.fromJson(Map<String, dynamic> json)
factory

Properties

chatType ↔ String?
getter/setter pair
from ↔ User
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
location ↔ Location?
getter/setter pair
offset ↔ String
getter/setter pair
query ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited