InlineQueryResultArticle class

Represents a link to an article or web page.

https://core.telegram.org/bots/api#inlinequeryresultarticle

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultArticle({required String id, String type = InlineQueryResult.typeArticle, required String title, required InputMessageContent inputMessageContent, InlineKeyboardMarkup? replyMarkup, String? url, bool? hideUrl, String? description, String? thumbnailUrl, String? thumbnailWidth, String? thumbnailHeight})
InlineQueryResultArticle.fromJson(Map<String, dynamic> json)
factory

Properties

description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideUrl ↔ bool?
getter/setter pair
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight ↔ String?
getter/setter pair
thumbnailUrl ↔ String?
getter/setter pair
thumbnailWidth ↔ String?
getter/setter pair
title ↔ String
getter/setter pair
type ↔ String
getter/setter pairoverride
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited