InlineQueryResultCachedGif class

Represents a link to an animated GIF file stored on the Telegram servers.

By default, this animated GIF file will be sent by the user with an optional caption. Alternatively, you can use inputMessageContent to send a message with specified content instead of the animation.

https://core.telegram.org/bots/api#inlinequeryresultcachedgif

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultCachedGif({required String id, String type = InlineQueryResult.typeGif, required String gifFileId, String? title, String? caption, String? parseMode, List<MessageEntity>? captionEntities, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent})
InlineQueryResultCachedGif.fromJson(Map<String, dynamic> json)
factory

Properties

caption ↔ String?
getter/setter pair
captionEntities ↔ List<MessageEntity>?
getter/setter pair
gifFileId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
parseMode ↔ String?
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited