InlineQueryResultCachedVideo class

Represents a link to a video file stored on the Telegram servers.

By default, this video file will be sent by the user with an optional caption. Alternatively, you can use inputMessageContent to send a message with the specified content instead of the video.

https://core.telegram.org/bots/api#inlinequeryresultcachedvideo

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultCachedVideo({required String id, String type = InlineQueryResult.typeVideo, required String videoFileId, required String title, String? description, String? caption, String? parseMode, List<MessageEntity>? captionEntities, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent})
InlineQueryResultCachedVideo.fromJson(Map<String, dynamic> json)
factory

Properties

caption ↔ String?
getter/setter pair
captionEntities ↔ List<MessageEntity>?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
parseMode ↔ String?
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair
type ↔ String
getter/setter pairoverride
videoFileId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited