InlineQueryResultContact class

Represents a contact with a phone number.

By default, the contact will be sent by the user. Alternatively, you can use inputMessageContent to send a message with the specified content instead of the contact.

Note: This will only work in Telegram versions released after 9 April, 2016. Older clients will ignore them.

https://core.telegram.org/bots/api#inlinequeryresultcontact

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultContact({required String id, String type = InlineQueryResult.typeContact, required String phoneNumber, required String firstName, String? lastName, String? vcard, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent, String? thumbnailUrl, int? thumbnailWidth, int? thumbnailHeight})
InlineQueryResultContact.fromJson(Map<String, dynamic> json)
factory

Properties

firstName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
lastName ↔ String?
getter/setter pair
phoneNumber ↔ String
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight ↔ int?
getter/setter pair
thumbnailUrl ↔ String?
getter/setter pair
thumbnailWidth ↔ int?
getter/setter pair
type ↔ String
getter/setter pairoverride
vcard ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited