InlineQueryResultDocument class

Represents a link to a file. By default, this file will be sent by the user with an optional caption.

Alternatively, you can use inputMessageContent to send a message with the specified content instead of the file. Currently, only .PDF and .ZIP files can be sent using this method.

Note: This will only work in Telegram versions released after 9 April, 2016. Older clients will ignore them.

https://core.telegram.org/bots/api#inlinequeryresultdocument

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultDocument({required String id, String type = InlineQueryResult.typeDocument, required String title, String? caption, String? parseMode, List<MessageEntity>? captionEntities, required String documentUrl, required String mimeType, String? description, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent, String? thumbnailUrl, int? thumbnailWidth, int? thumbnailHeight})
InlineQueryResultDocument.fromJson(Map<String, dynamic> json)
factory

Properties

caption ↔ String?
getter/setter pair
captionEntities ↔ List<MessageEntity>?
getter/setter pair
description ↔ String?
getter/setter pair
documentUrl ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
mimeType ↔ String
getter/setter pair
parseMode ↔ String?
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight ↔ int?
getter/setter pair
thumbnailUrl ↔ String?
getter/setter pair
thumbnailWidth ↔ int?
getter/setter pair
title ↔ String
getter/setter pair
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited