InlineQueryResultMpeg4Gif class

Represents a link to a video animation (H.264/MPEG-4 AVC video without sound).

By default, this animated MPEG-4 file will be sent by the user with optional caption. Alternatively, you can use inputMessageContent to send a message with the specified content instead of the animation.

https://core.telegram.org/bots/api#inlinequeryresultmpeg4gif

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultMpeg4Gif({required String id, String type = InlineQueryResult.typeMpeg4Gif, required String mpeg4Url, int? mpeg4Width, int? mpeg4Height, int? mpeg4Duration, required String thumbnailUrl, String? thumbnailMimeType, String? title, String? caption, String? parseMode, List<MessageEntity>? captionEntities, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent})
InlineQueryResultMpeg4Gif.fromJson(Map<String, dynamic> json)
factory

Properties

caption ↔ String?
getter/setter pair
captionEntities ↔ List<MessageEntity>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
mpeg4Duration ↔ int?
getter/setter pair
mpeg4Duration_ ↔ Duration?
getter/setter pair
mpeg4Height ↔ int?
getter/setter pair
mpeg4Url ↔ String
getter/setter pair
mpeg4Width ↔ int?
getter/setter pair
parseMode ↔ String?
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailMimeType ↔ String?
getter/setter pair
thumbnailUrl ↔ String
getter/setter pair
title ↔ String?
getter/setter pair
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited