InlineQueryResultVenue class

Represents a venue.

By default, the venue will be sent by the user. Alternatively, you can use inputMessageContent to send a message with the specified content instead of the venue.

Note: This will only work in Telegram versions released after 9 April, 2016. Older clients will ignore them.

https://core.telegram.org/bots/api#inlinequeryresultvenue

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultVenue({required String id, String type = InlineQueryResult.typeVenue, required double latitude, required double longitude, required String title, required String address, String? foursquareId, String? foursquareType, String? googlePlaceId, String? googlePlaceType, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent, String? thumbnailUrl, int? thumbnailWidth, int? thumbnailHeight})
InlineQueryResultVenue.fromJson(Map<String, dynamic> json)
factory

Properties

address ↔ String
getter/setter pair
foursquareId ↔ String?
getter/setter pair
foursquareType ↔ String?
getter/setter pair
googlePlaceId ↔ String?
getter/setter pair
googlePlaceType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
latitude ↔ double
getter/setter pair
longitude ↔ double
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight ↔ int?
getter/setter pair
thumbnailUrl ↔ String?
getter/setter pair
thumbnailWidth ↔ int?
getter/setter pair
title ↔ String
getter/setter pair
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited