InlineQueryResultVideo class

Represents a link to a page containing an embedded video player or a video file.

By default, this video file will be sent by the user with an optional caption. Alternatively, you can use inputMessageContent to send a message with the specified content instead of the video.

If an InlineQueryResultVideo message contains an embedded video (e.g., YouTube), you must replace its content using inputMessageContent.

https://core.telegram.org/bots/api#inlinequeryresultvideo

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultVideo({required String id, String type = InlineQueryResult.typeVideo, required String videoUrl, required String mimeType, required String thumbnailUrl, required String title, String? caption, String? parseMode, int? videoWidth, int? videoHeight, int? videoDuration, String? description, List<MessageEntity>? captionEntities, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent})
InlineQueryResultVideo.fromJson(Map<String, dynamic> json)
factory

Properties

caption ↔ String?
getter/setter pair
captionEntities ↔ List<MessageEntity>?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairoverride
inputMessageContent ↔ InputMessageContent?
getter/setter pair
mimeType ↔ String
getter/setter pair
parseMode ↔ String?
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl ↔ String
getter/setter pair
title ↔ String
getter/setter pair
type ↔ String
getter/setter pairoverride
videoDuration ↔ int?
getter/setter pair
videoDuration_ ↔ Duration?
getter/setter pair
videoHeight ↔ int?
getter/setter pair
videoUrl ↔ String
getter/setter pair
videoWidth ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited