InlineQueryResultsButton class

This object represents a button to be shown above inline query results. You must use exactly one of the optional fields.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InlineQueryResultsButton({required String text, WebAppInfo? webApp, String? startParameter})
InlineQueryResultsButton.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startParameter ↔ String?
getter/setter pair
text ↔ String
getter/setter pair
webApp ↔ WebAppInfo?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited