InputMedia class

This object represents the content of a media message to be sent.

It should be one of

https://core.telegram.org/bots/api#inputmedia

Implementers
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InputMedia({required String type, required String media, String? caption, String? parseMode, List<MessageEntity>? captionEntities, MultipartFile? mediaFile})
InputMedia.fromJson(Map<String, dynamic> json)
factory

Properties

caption ↔ String?
getter/setter pair
captionEntities ↔ List<MessageEntity>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
media ↔ String
getter/setter pair
mediaFile ↔ MultipartFile?
getter/setter pair
parseMode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

typeAnimation → const String
typeAudio → const String
typeDocument → const String
typePhoto → const String
typeVideo → const String