InputMediaAudio class

Represents an audio file to be treated as music to be sent.

https://core.telegram.org/bots/api#inputmediaaudio

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InputMediaAudio({String type = InputMedia.typeAudio, required String media, String? thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, int? duration, String? performer, String? title})
InputMediaAudio.fromFile({required File media, String? thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, int? duration, String? performer, String? title})
factory
InputMediaAudio.fromFileWithThumbnailFile({required File media, required File thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, int? duration, String? performer, String? title})
factory
InputMediaAudio.fromJson(Map<String, dynamic> json)
factory
InputMediaAudio.withThumbnailFile({required File thumbnail, required String media, String? caption, String? parseMode, List<MessageEntity>? captionEntities, int? duration, String? performer, String? title})
factory

Properties

caption ↔ String?
getter/setter pairoverride
captionEntities ↔ List<MessageEntity>?
getter/setter pairoverride
duration ↔ int?
getter/setter pair
duration_ ↔ Duration?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
media ↔ String
getter/setter pairoverride
mediaFile ↔ MultipartFile?
getter/setter pairoverride
parseMode ↔ String?
getter/setter pairoverride
performer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ String?
getter/setter pairoverride
thumbnailFile ↔ MultipartFile?
getter/setter pairoverride
title ↔ String?
getter/setter pair
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited