InputMediaDocument class

Represents a general file to be sent.

https://core.telegram.org/bots/api#inputmediadocument

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InputMediaDocument({String type = InputMedia.typeDocument, required String media, String? thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, bool? disableContentTypeDetection})
InputMediaDocument.fromFile({required File media, String? thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, bool? disableContentTypeDetection})
factory
InputMediaDocument.fromFileWithThumbnailFile({required File media, required File thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, bool? disableContentTypeDetection})
factory
InputMediaDocument.fromJson(Map<String, dynamic> json)
factory
InputMediaDocument.withThumbnailFile({required String media, required File thumbnail, String? caption, String? parseMode, List<MessageEntity>? captionEntities, bool? disableContentTypeDetection})
factory

Properties

caption ↔ String?
getter/setter pairoverride
captionEntities ↔ List<MessageEntity>?
getter/setter pairoverride
disableContentTypeDetection ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
media ↔ String
getter/setter pairoverride
mediaFile ↔ MultipartFile?
getter/setter pairoverride
parseMode ↔ String?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ String?
getter/setter pairoverride
thumbnailFile ↔ MultipartFile?
getter/setter pairoverride
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited