InputSticker class

This object describes a sticker to be added to a sticker set.

https://core.telegram.org/bots/api#inputsticker

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

InputSticker({required String sticker, required List<String> emojiList, MaskPosition? maskPosition, List<String>? keywords, MultipartFile? stickerFile})
InputSticker.file({required File sticker, required List<String> emojiList, MaskPosition? maskPosition, List<String>? keywords})
factory
InputSticker.fromJson(Map<String, dynamic> json)
factory

Properties

emojiList ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keywords ↔ List<String>?
getter/setter pair
maskPosition ↔ MaskPosition?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticker ↔ String
getter/setter pair
stickerFile ↔ MultipartFile?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited