Invoice class

This object contains basic information about an invoice.

https://core.telegram.org/bots/api#invoice

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Invoice({required String title, required String description, required String startParameter, required String currency, required int totalAmount})
Invoice.fromJson(Map<String, dynamic> json)
factory

Properties

currency ↔ String
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startParameter ↔ String
getter/setter pair
title ↔ String
getter/setter pair
totalAmount ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited