KeyboardButtonRequestChat class

This object defines the criteria used to request a suitable chat. The identifier of the selected chat will be shared with the bot when the corresponding button is pressed.

https://core.telegram.org/bots/api#keyboardbuttonrequestchat

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

KeyboardButtonRequestChat({required int requestId, required bool chatIsChannel, bool? charIsForum, bool? chatHasUsername, bool? chatIsCreated, ChatAdministratorRights? userAdministratorRights, ChatAdministratorRights? botAdministratorRights, bool? botIsMember})
KeyboardButtonRequestChat.fromJson(Map<String, dynamic> json)
factory

Properties

botAdministratorRights ↔ ChatAdministratorRights?
getter/setter pair
botIsMember ↔ bool?
getter/setter pair
charIsForum ↔ bool?
getter/setter pair
chatHasUsername ↔ bool?
getter/setter pair
chatIsChannel ↔ bool
getter/setter pair
chatIsCreated ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAdministratorRights ↔ ChatAdministratorRights?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited