KeyboardButtonRequestUser class

This object defines the criteria used to request a suitable user. The identifier of the selected user will be shared with the bot when the corresponding button is pressed.

https://core.telegram.org/bots/api#keyboardbuttonrequestuser

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

KeyboardButtonRequestUser({required int requestId, bool? userIsBot, bool? userIsPremium})
KeyboardButtonRequestUser.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIsBot ↔ bool?
getter/setter pair
userIsPremium ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited