PassportElementErrorFile class

Represents an issue with a document scan.

The error is considered resolved when the file with the document scan changes.

https://core.telegram.org/bots/api#passportelementerrorfile

Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

PassportElementErrorFile({required String source, required String type, required String message, required String fileHash})
PassportElementErrorFile.fromJson(Map<String, dynamic> json)
factory

Properties

fileHash ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String
getter/setter pairoverride
type ↔ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited