PassportFile class

This object represents a file uploaded to Telegram Passport.

Currently all Telegram Passport files are in JPEG format when decrypted and don't exceed 10MB.

https://core.telegram.org/bots/api#passportfile

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

PassportFile({required String fileId, required String fileUniqueId, required int fileSize, required int fileDate})
PassportFile.fromJson(Map<String, dynamic> json)
factory

Properties

fileDate ↔ int
getter/setter pair
fileDate_ ↔ DateTime
getter/setter pair
fileId ↔ String
getter/setter pair
fileSize ↔ int
getter/setter pair
fileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited