Poll class

This object represents one size of a photo or a file / sticker thumbnail.

https://core.telegram.org/bots/api#poll

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Poll({required String id, required String question, required List<PollOption> options, required int totalVoterCount, required bool isClosed, required bool isAnonymous, required String type, required bool allowsMultipleAnswers, int? correctOptionId, String? explanation, List<MessageEntity>? explanationEntities, int? openPeriod, int? closeDate})
Poll.fromJson(Map<String, dynamic> json)
factory

Properties

allowsMultipleAnswers ↔ bool
getter/setter pair
closeDate ↔ int?
getter/setter pair
closeDate_ ↔ DateTime?
getter/setter pair
correctOptionId ↔ int?
getter/setter pair
explanation ↔ String?
getter/setter pair
explanationEntities ↔ List<MessageEntity>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isAnonymous ↔ bool
getter/setter pair
isClosed ↔ bool
getter/setter pair
openPeriod ↔ int?
getter/setter pair
openPeriod_ ↔ Duration?
getter/setter pair
options ↔ List<PollOption>
getter/setter pair
question ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalVoterCount ↔ int
getter/setter pair
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

typeQuiz → const String
typeRegular → const String