PollOption class

This object represents one size of a photo or a file / sticker thumbnail.

https://core.telegram.org/bots/api#polloption

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

PollOption({required String text, required int voterCount})
PollOption.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
voterCount ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited