PreCheckoutQuery class

This object contains information about an incoming pre-checkout query.

https://core.telegram.org/bots/api#precheckoutquery

Implementers
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

PreCheckoutQuery({required String id, required User from, required String currency, required int totalAmount, required String invoicePayload, String? shippingOptionId, OrderInfo? orderInfo})
PreCheckoutQuery.fromJson(Map<String, dynamic> json)
factory

Properties

currency ↔ String
getter/setter pair
from ↔ User
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
invoicePayload ↔ String
getter/setter pair
orderInfo ↔ OrderInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingOptionId ↔ String?
getter/setter pair
totalAmount ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited