ShippingAddress class

This object represents a shipping address.

https://core.telegram.org/bots/api#shippingaddress

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ShippingAddress({required String countryCode, required String state, required String city, required String streetLine1, required String streetLine2, required String postCode})
ShippingAddress.fromJson(Map<String, dynamic> json)
factory

Properties

city ↔ String
getter/setter pair
countryCode ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postCode ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pair
streetLine1 ↔ String
getter/setter pair
streetLine2 ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited