Sticker class

This object represents a sticker.

https://core.telegram.org/bots/api#sticker

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Sticker({required String fileId, required String fileUniqueId, required int width, required int height, required bool isAnimated, required bool isVideo, PhotoSize? thumbnail, String? emoji, String? setName, File? premiumAnimation, MaskPosition? maskPosition, String? customEmojiId, bool? needsRepainting, int? fileSize})
Sticker.fromJson(Map<String, dynamic> json)
factory

Properties

customEmojiId ↔ String?
getter/setter pair
emoji ↔ String?
getter/setter pair
fileId ↔ String
getter/setter pair
fileSize ↔ int?
getter/setter pair
fileUniqueId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
isAnimated ↔ bool
getter/setter pair
isVideo ↔ bool
getter/setter pair
maskPosition ↔ MaskPosition?
getter/setter pair
needsRepainting ↔ bool?
getter/setter pair
premiumAnimation ↔ File?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setName ↔ String?
getter/setter pair
thumbnail ↔ PhotoSize?
getter/setter pair
width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited