SuccessfulPayment class

This object contains basic information about a successful payment.

https://core.telegram.org/bots/api#successfulpayment

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

SuccessfulPayment({required String currency, required int totalAmount, required String invoicePayload, String? shippingOptionId, OrderInfo? orderInfo, required String telegramPaymentChargeId, required String providerPaymentChargeId})
SuccessfulPayment.fromJson(Map<String, dynamic> json)
factory

Properties

currency ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invoicePayload ↔ String
getter/setter pair
orderInfo ↔ OrderInfo?
getter/setter pair
providerPaymentChargeId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingOptionId ↔ String?
getter/setter pair
telegramPaymentChargeId ↔ String
getter/setter pair
totalAmount ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited