User class

This object represents a Telegram user or bot.

https://core.telegram.org/bots/api#user

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

User({required int id, required bool isBot, required String firstName, String? lastName, String? username, String? languageCode, bool? isPremium, bool? addedToAttachmentMenu, bool? canJoinGroups, bool? canReadAllGroupMessages, bool? supportsInlineQueries})
User.fromJson(Map<String, dynamic> json)
factory

Properties

addedToAttachmentMenu ↔ bool?
getter/setter pair
canJoinGroups ↔ bool?
getter/setter pair
canReadAllGroupMessages ↔ bool?
getter/setter pair
firstName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
isBot ↔ bool
getter/setter pair
isPremium ↔ bool?
getter/setter pair
languageCode ↔ String?
getter/setter pair
lastName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsInlineQueries ↔ bool?
getter/setter pair
username ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited