UserShared class

This object contains information about the user whose identifier was shared with the bot using a KeyboardButtonRequestUser button.

https://core.telegram.org/bots/api#usershared

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

UserShared({required int requestId, required int userId})
UserShared.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited