HttpClientException class

Implemented types

Constructors

HttpClientException(int code, String description, ResponseParameters? parameters)

Properties

code ↔ int
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parameters ↔ ResponseParameters?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isHttpClientError() → bool
isTooManyRequests() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited